Learn R Programming

gogarch (version 0.7-0)

BVDW: Dow Jones Industrial Average and Nasdaq stock indices

Description

Levels of the Dow Jones Industrial Average and NASDAQ stock indices for the period 03/23/1990 until 03/23/2000.

Usage

data(BVDW)

Arguments

encoding

latin1

source

Boswijk, H. Peter and van der Weide, Roy (2006), Wake me up before you GO-GARCH, Tinbergen Institute Discussion Paper, TI 2006-079/4, University of Amsterdam and Tinbergen Institute.

Details

This data set has been utilized in the source below and was kindly provided by Roy van der Weide.

References

http://www.nasdaq.com, http://www.djindexes.com

See Also

VDW

Examples

Run this code
data(BVDW)
str(BVDW)

Run the code above in your browser using DataLab