Learn R Programming

gogarch (version 0.7-0)

BVDWSTOXX: Sector indices of the EURO STOXX 600

Description

The data frame contains the following sector indices of the EURO STOXX 600 index: Automobiles & Parts, Banks, Basic Resources, Chemicals, Construction and Materials, Financial Services, Food & Beverages, Health Care, Industrial Goods & Services, Insurance, Media, Oil & Gas, Technology, Telecommunications and Utilities. The data range is from 31th December 1986 until 21st November 2008.

Usage

data(BVDWSTOXX)

Arguments

encoding

latin1

source

http://www.stoxx.com

References

Boswijk, H. Peter and van der Weide, Roy (2009), Method of Moments Estimation of GO-GARCH Models, Working Paper, University of Amsterdam, Tinbergen Institute and World Bank.

Examples

Run this code
data(BVDWSTOXX)
str(BVDWSTOXX)

Run the code above in your browser using DataLab