Learn R Programming

gogarch (version 0.7-0)

Goestica-class: Class "Goestica": GO-GARCH models estimated by fast ICA

Description

This class contains the GoGARCH class and has the mixing matrix $A$ as additional slot.

Arguments

encoding

latin1

Objects from the Class

Objects can be created by calls of the form new("Goestmm", ...), or with the function gogarch whereby method = "ica" has been set.

Extends

Class "GoGARCH", directly. Class "Goinit", by class "GoGARCH", distance 2.

References

Broda, S.A. and Paolella, M.S. (2008): CHICAGO: A Fast and Accurate Method for Portfolio Risk Calculation, Swiss Finance Institute, Research Paper Series No. 08-08, Zuerich.

See Also

GoGARCH, Goinit, Gosum, Gopredict, goest-methods and gogarch