Learn R Programming

gogarch (version 0.7-0)

Goestmm-class: Class "Goestmm": Go-GARCH models estimated by Methods of Moments

Description

This class contains the GoGARCH class and has the weights vector and the matched orthogonal matrices $U$ as additional slots.

Arguments

encoding

latin1

Objects from the Class

Objects can be created by calls of the form new("Goestmm", ...), or with the function gogarch whereby method = "mm" has been set.

Extends

Class "GoGARCH", directly. Class "Goinit", by class "GoGARCH", distance 2.

References

Boswijk, H. Peter and van der Weide, Roy (2009), Method of Moments Estimation of GO-GARCH Models, Working Paper, University of Amsterdam, Tinbergen Institute and World Bank.

See Also

GoGARCH, Goinit, Gosum, Gopredict, goest-methods, gogarch, Umatch