Orthom-class: Class "Orthom": Orthogonal matrices
Description
This class defines an orthogonal matrix, which is characterized by
$det(M) = 1$ and $M M' = I$.encoding
latin1Objects from the Class
Objects can be created by calls of the form new("Orthom",
...). In addition the function UprodR returns an object of
formal class Orthom.concept
Orthogonal Matrix