Learn R Programming

gogarch (version 0.7-0)

cora: Autocorrelations of a Matrix Process

Description

This function computes the autocorrelation matrix for a given lag. For instance, it is used for estimating GO-GARCH models whence the method of moments is utilized.

Usage

cora(SSI, lag = 1, standardize = TRUE)

Arguments

SSI
Array with dimension dim = c(m, m, n)
lag
Integer, the lag for which the autocorrelation is computed.
standardize
Logical, if TRUE (the default), the autocorrelation matrix is computed, otherwise the autocovariance matrix.

Value

  • coraMatrix with dimension dim = c(m, m).

encoding

latin1

Details

This function computes the autocorrelation matrix according to: $$\hat{\Gamma}_k (s) = \frac{1}{n} \sum_{t = k + 1}^n S_t S_{t-k}$$ $$\hat{\Phi}_k (s) = \hat{\Gamma}_0 (s)^{-1/2} \hat{\Gamma}_k (s) \hat{\Gamma}_0 (s)^{-1/2}$$ It is computationally assured that $\hat{\Phi}_k (s)$ is symmetric by setting it equal to: $\hat{\Phi}_k (s) = \frac{1}{2}(\hat{\Phi}_k (s) + \hat{\Phi}_k (s)')$. The standardization matrix $\hat{\Gamma}_0 (s)^{-1/2}$ is derived from the singular value decomposition of the co-variance matrix at lag zero.

References

Boswijk, H. Peter and van der Weide, Roy (2009), Method of Moments Estimation of GO-GARCH Models, Working Paper, University of Amsterdam, Tinbergen Institute and World Bank.

See Also

gogarch