Learn R Programming

gogarch (version 0.7-0)

gollh: Log-Likelihood function of GO-GARCH models

Description

This function returns the negative of the log-Likelihood function for GO-GARCH models.

Usage

gollh(params, object, garchlist)

Arguments

params
Vector of initial values for theta.
object
An object of class Goinit or an extension thereof.
garchlist
List, elements are passed to garchFit.

Value

  • negllScalar, the negative value of the log-Likelihood function.

encoding

latin1

concept

  • GO-GARCH
  • Likelihood

Details

The log-Likelihood function of GO-GARCH models is given as: $$L_{\theta, \alpha, \beta} = - \frac{1}{2} \sum_{t=1}^T m \log(2\pi) + \log|Z_\theta Z_\theta '| + \log|H_t| + y' H_t^{-1}y_t$$ whereby $Z = P \Delta^{\frac{1}{2}} U_0$, $y_t = Z^{-1}x_t$ and $H_t$ is the conditional variance matrix of the independent components.

References

Van der Weide, Roy (2002), GO-GARCH: A Multivariate Generalized Orthogonal GARCH Model, Journal of Applied Econometrics, 17(5), 549 -- 564.

See Also

garchFit